package com.example.parkreminder;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.PowerManager;

import androidx.core.app.NotificationCompat;

public class AlertReceiver extends BroadcastReceiver {

    public String TAG = "PowerManager";
    @Override
    public void onReceive(Context context, Intent intent) {
        PowerManager powerManager = (PowerManager) context.getSystemService(Context.POWER_SERVICE);
        // Get the data that you passed
        String street = intent.getStringExtra("street");
        /*
        high power consumption:
        FULL_WAKE_LOCK or SCREEN_BRIGHT_WAKE_LOCK

        least power-consuming:
        PARTIAL_WAKE_LOCK */

        PowerManager.WakeLock wakeLock = powerManager.newWakeLock(PowerManager.PARTIAL_WAKE_LOCK, TAG);

        wakeLock.acquire();
        setNotification(context, street);
        wakeLock.release();
    }

    private void setNotification(Context context, String street) {
        NotificationHelper notificationHelper = new NotificationHelper(context,street);
        NotificationCompat.Builder builder = notificationHelper.getNotification();
        notificationHelper.getManager().notify(MainActivity.REQUEST_CODE, builder.build());
    }

    static class NotificationHelper {
        private final String channelID = "channelID";
        private NotificationManager mManager;
        private final String street;
        private final Context context;

        public NotificationHelper(Context context, String street) {
            this.context = context;
            this.street = street;

            createChannel();
        }
        private void createChannel() {
            String channelName = "General";

            NotificationChannel channel = new NotificationChannel(channelID, channelName, NotificationManager.IMPORTANCE_HIGH);
            getManager().createNotificationChannel(channel);
        }
        public NotificationManager getManager() {
            if (mManager == null)
                mManager = (NotificationManager) context.getSystemService(Context.NOTIFICATION_SERVICE);
            return mManager;
        }

        public NotificationCompat.Builder getNotification() {
            return new NotificationCompat.Builder(context, channelID)
                    .setContentTitle("Hey! Don't Where You Park")
                    .setContentText("" + street)
                    .setSmallIcon(R.drawable.ic_icon_car_black);
        }
    }
}
