package com.example.parkreminder;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

import androidx.annotation.Nullable;

public class Database extends SQLiteOpenHelper {
    public static final String DATABASE_NAME = "park.db";

    private static final String TABLE_NAME = "history_table";

    public static final String ID =         "id";
    public static final String STREET =     "street";
    public static final String LONGITUDE =  "lon";
    public static final String LATITUDE =   "lat";
    public static final String TIMESTAMP =  "time";


    public Database(@Nullable Context context) {
        super(context, DATABASE_NAME, null, 1);
    }

    private void createTableParking(SQLiteDatabase db){
        db.execSQL(" CREATE TABLE " + TABLE_NAME + " (" +
                ID +          " INTEGER PRIMARY KEY AUTOINCREMENT, " +
                STREET +      " TEXT NOT NULL, " +     // PLACE
                LONGITUDE +   " TEXT, " +              // LONGITUDE
                LATITUDE +    " TEXT, " +              // LATITUDE
                TIMESTAMP +   " TEXT );"               // TIMESTAMP ResId
        );
    }

    @Override
    public void onCreate(SQLiteDatabase sqLiteDatabase) {
        createTableParking(sqLiteDatabase);
    }

    @Override
    public void onUpgrade(SQLiteDatabase sqLiteDatabase, int i, int i1) {
        sqLiteDatabase.execSQL("DROP TABLE IF EXISTS " + TABLE_NAME+ ";");
    }

    public long insert(String street, double lon, double lat, String timeStamp){
        ContentValues contentValues = new ContentValues();

        contentValues.put(STREET, street);
        contentValues.put(LONGITUDE, String.valueOf(lon));
        contentValues.put(LATITUDE, String.valueOf(lat));
        contentValues.put(TIMESTAMP, timeStamp);

        return getDatabaseInstance().insert(TABLE_NAME, null, contentValues);
    }

    public Cursor fetchAll(){
        return getDatabaseInstance().rawQuery("SELECT * FROM " + TABLE_NAME, null);
    }

    public Cursor fetchLast(){
        return getDatabaseInstance().rawQuery("SELECT * FROM " + TABLE_NAME + " ORDER BY " + ID + " DESC LIMIT 1 ", null);
    }

    public SQLiteDatabase getDatabaseInstance(){
        return this.getWritableDatabase();
    }
}
